#include <iostream>
#include <fstream>
#include <string>
#include <sstream>
#include <vector>
#include <algorithm>

using namespace std;

#define BR endl

const int max_len = 500;
const int points_per_test = 5;

const int AC = 0;
const int WA = 1;
const int UNHANDLED_ERROR = 3;

typedef vector<pair<int, int> > VPII;

vector<int> T, a, b;
int tests_num;
VPII ans, out;

bool read_single_test(ifstream &f, VPII &res)
{
    int n;
    f >> n;
    if (!f) return false;
    for (int i = 0; i < n; i++) {
        int x, y;
        f >> x >> y;
        if (!f) return false;
        res.push_back(make_pair(x, y));
    }
    return true;
}

bool check_single_test(const VPII &v, string &comment, int T, int a, int b)
{
    int n = v.size();
    if (n > max_len) {
        comment = "long";
        return false;
    }
    
    int t = 0;
    int i;
    int sa = 0, sb = 0;
    
    for (i = 0; i < n; i++) {
        int delta;
        if (v[i].first == t+sa) delta = sa;
        else if (v[i].first == t+sb) delta = sb;
        else {
            ostringstream ss;
            ss << "( at " << v[i].first;
            comment = ss.str();
            return false;
        }
        if (!delta && i) {
            comment = "t_i-1 = t_i";
            return false;
        }
        
        t += delta;
        sa -= delta;
        if (sa < 0) sa = 0;
        sb -= delta;
        if (sb < 0) sb = 0;
        
        switch (v[i].second) {
        case 1:
            sa = a - sa;
            break;
        case 2:
            sb = b - sb;
            break;
        case 3:
            sa = a - sa;
            sb = b - sb;
            break;
        default:
            comment = "( mask";
            return false;
        }
    }
    
    t += max(sa, sb);
    
    if (t != T) {
        ostringstream ss;
        ss << t << " != " << T;
        comment = ss.str();
        return false;
    }

    comment = "+";
    return true;
}

//возвращает количество баллов и комментарий
int process(ifstream &f, string& comment)
{
    ostringstream ss; 
    int points = 0;
    for (int i = 0; i < tests_num; i++) {
        VPII t;
        string s;
        if (!read_single_test(f, t)) {
            s = "PE";
        } else {
            if (check_single_test(t, s, T[i], a[i], b[i]))
                points += points_per_test;
        }
        ss << i+1 << ": " << s << BR;
    }
    comment = ss.str();
    return points;
}

int main(int argc, char* argv[])
{
    ifstream f_in(argv[1]);
    ifstream f_out(argv[2]);
    ifstream f_ans(argv[3]);

    f_in >> tests_num;
    T.resize(tests_num);
    a.resize(tests_num);
    b.resize(tests_num);
    for (int i = 0; i < tests_num; i++) {
        f_in >> T[i] >> a[i] >> b[i];
    }

    string jury_comment, cont_comment;
    int jury_points = process(f_ans, jury_comment);
    int cont_points = process(f_out, cont_comment);
    
    if (jury_points != points_per_test * tests_num) {
        cout << 0 << BR << jury_comment;
        return UNHANDLED_ERROR;
    }
    cout << cont_points << BR << cont_comment;
    if (!cont_points) return WA;
   
    return AC;
}

